@@ -1,4 +1,6 @@
-void pmcc(const float * vectsa, size_t na,
+typedef enum useObs {everything, pairwiseComplete} UseObs; 
+
+void pmcc(UseObs whichObs, const float * vectsa, size_t na,
 	const float * vectsb, size_t nb, size_t dim, float * numPairs, 
 	float * correlations, float * signifs);
 
